@@ -19,7 +19,7 @@ DictFileFieldSelector::DictFileFieldSelector(KConfigSkeleton *config, const QStr
     : DictionaryPreferenceDialog(parent, dictionaryTypeName)
     , m_dictName(dictionaryTypeName)
 {
-    QVBoxLayout *newTabLayout = new QVBoxLayout();
+    auto newTabLayout = new QVBoxLayout();
 
     // Make selection box
     m_listView = new KActionSelector();
@@ -47,10 +47,6 @@ DictFileFieldSelector::DictFileFieldSelector(KConfigSkeleton *config, const QStr
     updateWidgets();
 }
 
-DictFileFieldSelector::~DictFileFieldSelector()
-{
-}
-
 void DictFileFieldSelector::addAvailable(const QStringList &list)
 {
     m_completeList += list;
@@ -136,3 +132,5 @@ void DictFileFieldSelector::writeToPrefs()
 
     m_config->save();
 }
+
+#include "moc_dictfilefieldselector.cpp"
